#
# spec file for package chrome-gnome-shell
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           chrome-gnome-shell
Version:        10
Release:        lp150.1.3
Summary:        GNOME Shell integration for Chrome Extension compatible browsers
License:        GPL-3.0+
Group:          Productivity/Networking/Web/Browsers
Url:            https://wiki.gnome.org/Projects/GnomeShellIntegrationForChrome
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  jq
BuildRequires:  p7zip
BuildRequires:  python3-base
Requires:       python3-requests
# Auto-install when the user uses GNOME Shell and any of the (known) supported browsers
Supplements:    packageand(gnome-shell:MozillaFirefox)
Supplements:    packageand(gnome-shell:chromium)
Supplements:    packageand(gnome-shell:google-chrome-stable)
Supplements:    packageand(gnome-shell:opera)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Browser extension for Google Chrome/Chromium, Firefox, Vivaldi, Opera (and other
Browser Extension, Chrome Extension or WebExtensions capable browsers) and native
host messaging connector that provides integration with GNOME Shell and the
corresponding extensions repository https://extensions.gnome.org.

%prep
%setup -q

%build
%cmake -DPYTHON_EXECUTABLE=$(which python3)
make %{?_smp_mflags}

%install
%cmake_install

%files
%defattr(-,root,root)
%doc LICENSE README.md NEWS
%config %{_sysconfdir}/chromium/
%config %{_sysconfdir}/opt/chrome/
%{_bindir}/chrome-gnome-shell
%{python3_sitelib}/chrome_gnome_shell-0.0.0-*egg-info
%{_libdir}/mozilla/
%{_datadir}/applications/org.gnome.ChromeGnomeShell.desktop
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/services/org.gnome.ChromeGnomeShell.service
%{_datadir}/icons/gnome/

%changelog
* Mon Feb  5 2018 bjorn.lie@gmail.com
- Update to version 10:
  + FreeBSD is supported again.
  + Enabled GNOME Shell extensions synchronization in Firefox.
  + Added option to check updates of enabled only GNOME Shell
    extensions.
  + Added GNOME proxy support for update checks.
  + Update errors will not produce desktop notifications anymore.
    All errors now goes to browser console.
  + Chrome managed policies no longer got installed so browser
    extensions will not be force installed along with connector.
  + It's possible to use inline installation of browser extensions
    through https://extensions.gnome.org website now.
  + Added light icon for dark browser themes. Use options page to
    switch icon.
  + Various fixes for options page in Firefox.
  + Updated translations.
- Drop chrome-gnome-shell-nb-translation.patch: Fixed upstream.
- No longer rm chrome-gnome-shell.json, upstream stopped installing
  it.
* Fri Nov 24 2017 zaitor@opensuse.org
- Add chrome-gnome-shell-nb-translation.patch: Add Norwegian
  Bokmål translation.
* Mon Nov  6 2017 dimstar@opensuse.org
- Allow the plugin to be disabled by removing the force-enabled
  policy from upstream (boo#1061278).
* Thu Nov  2 2017 dimstar@opensuse.org
- Port to python3:
  + BuildRequire python3-base: /usr/bin/python3 is not implicit
    available in the buildroot yet.
  + Replace python-requests Requires with python3-requests.
  + Pass -DPYTHON_EXECUTABLE to cmake, pointing to
    /usr/bin/python3.
- Drop icon_theme_cache_post/postun scriptlets: no longer needed,
  since file triggers hancdle icon cache updates now.
- Add gobject-introspection BuildRequires: allow rpm to find/add
  typelib() dependencies.
* Thu May 18 2017 zaitor@opensuse.org
- Update to version 9:
  + connector:
  - Handle command line argument outside of GApplication.
  - Fix gsettings GNOME Shell schema lookup.
  - Fixed possible AttributeError.
  - Fixed Ctrl spelling.
  + compatibility:
  - Fixed external messaging for Firefox 54.
  - Updated to Firefox 52.
  + Removed redundant line forgotten in previous commit.
  + firefox:
  - Restrict maximum version to 53.
  - Show usefull error message in case native connector not
    installed.
  + api: show errror instead of warning in case initialization
    failure.
  + Improved error handling when GNOME Shell is not installed or
    not running.
  + options: allow html in error messages.
  + sync:
  - Avoid synchronization of disabled extensions during sleep
    state.
  - Increased idle queue timeout.
  + update-check: make python-requests dependency optional.
  + constants: drop old string.
  + doap: fix JavaScript spelling.
  + extension: open Shell extensions website on icon click.
  + i18n:
  - Regenerate template.
  - Explicitly distinguish "browser extension" and "Shell
    extension".
  - Fix error message.
  - Update list of supported locales.
  - Regenerate locales.
  + Updated translations.
* Sat Mar  4 2017 zaitor@opensuse.org
- Update to version 8.2:
  + ubuntu:
  - Added control.in that is needed for gnome-pkg-tools.
  - Fixed python 3 detection.
  + notifications: Fixed inter-frame communication.
  + api:
  - Do not expose api if GNOME Shell is not running.
  - Do not expose api version on initialize failure.
  + update-check: Fixed in-frame communication.
  + i18n: Regenerate locales.
  + Updated translations.
* Sun Feb 12 2017 zaitor@opensuse.org
- Update to version 8.1:
  + Added check to make sure that "enabled-extensions" GNOME Shell
    setting does not contains duplicated values (bgo#777650).
  + Fixed error that breaks update check if there was extension
    installed without "version" key in manifest.
  + Fixed error that prevents error message to be shown when update
    check is failed.
  + Fixed connector segfault on browser close.
  + Fixed possible error in synchronization process that may delete
    some extensions.
  + Updated translations.
- Drop chrome-gnome-shell-commit-dca4a35.patch: Fixed upstream.
- Use conditional to allow packaging for older versions of
  openSUSE.
* Sat Feb  4 2017 duncansreeves@gmail.com
- Added chrome-gnome-shell-commit-dca4a35.patch: Fix connector: do
  not use get_dbus_connection after GApplication was released
  (gh#nE0sIghT/chrome-gnome-shell-mirror#27).
* Wed Jan 25 2017 dimstar@opensuse.org
- Initial package, version 8.
